==> neon_skill_wikipedia-0.0.1a2-py3-none-any.whl: skill_wikipedia/README.md <==
# <img src='https://raw.githack.com/FortAwesome/Font-Awesome/master/svgs/brands/wikipedia-w.svg' card_color='#000000' width='50' height='50' style='vertical-align:bottom'/> Wikipedia
Wikipedia

![](./logo.png)

## About 
Query [Wikipedia](https://www.wikipedia.org) for answers to all your questions.  Get just a summary, or ask for more to get in-depth information.
 
 This Skill uses the [Wikipedia for humans](https://github.com/HelloChatterbox/wikipedia_for_humans). 

NOTE: this will blacklist the official mycroft skill

![](./gui.gif)
![](./gui2.gif)

## Examples 
* "Tell me about Elon Musk"
* "Tell me about beans"
* "Random wikipedia"
* "Check Wikipedia for beans"
* "Tell me about the Pembroke Welsh Corgi"
* "Search for chocolate"
* "More information" (followup after an initial summary)
* "Tell me More" (followup after an initial summary)

# Platform support

- :heavy_check_mark: - tested and confirmed working
- :x: - incompatible/non-functional
- :question: - untested
- :construction: - partial support

|     platform    |   status   |  tag  | version | last tested | 
|:---------------:|:----------:|:-----:|:-------:|:-----------:|
|    [Chatterbox](https://hellochatterbox.com)   | :question: |  dev  |         |    never    | 
|     [HolmesV](https://github.com/HelloChatterbox/HolmesV)     | :question: |  dev  |         |    never    | 
|    [LocalHive](https://github.com/JarbasHiveMind/LocalHive)    | :question: |  dev  |         |    never    |  
|  [Mycroft Mark1](https://github.com/MycroftAI/enclosure-mark1)    | :question: |  dev  |         |    never    | 
|  [Mycroft Mark2](https://github.com/MycroftAI/hardware-mycroft-mark-II)    | :question: |  dev  |         |    never    |  
|    [NeonGecko](https://neon.ai)      | :question: |  dev  |         |    never    |   
|       [OVOS](https://github.com/OpenVoiceOS)        | :question: |  dev  |         |    never    |    
|     [Picroft](https://github.com/MycroftAI/enclosure-picroft)       | :question: |  dev  |         |    never    |  
| [Plasma Bigscreen](https://plasma-bigscreen.org/)  | :question: |  dev  |         |    never    |  

- `tag` - link to github release / branch / commit
- `version` - link to release/commit of platform repo where this was tested

## Credits
[JarbasAl](https://github.com/JarbasAl)
[NeonDaniel](https://github.com/NeonDaniel)

## Category
**Information**

## Tags
#wikipedia
#encyclopedia
#general-knowledge
#wiki
#question
#query

==> neon_skill_wikipedia-0.4.2a1-py3-none-any.whl: skill_wikipedia/README.md <==
# <img src='https://raw.githack.com/FortAwesome/Font-Awesome/master/svgs/brands/wikipedia-w.svg' card_color='#000000' width='50' height='50' style='vertical-align:bottom'/> Wikipedia
Wikipedia

![](./logo.png)

## About 
Query [Wikipedia](https://www.wikipedia.org) for answers to all your questions.  Get just a summary, or ask for more to get in-depth information.
 
 This Skill uses the [Wikipedia for humans](https://github.com/HelloChatterbox/wikipedia_for_humans). 

NOTE: this will blacklist the official mycroft skill

![](./gui.gif)
![](./gui2.gif)

## Examples 
* "Tell me about Elon Musk."
* "Tell me about beans."
* "Random Wikipedia."
* "Check Wikipedia for beans."
* "Tell me about the Pembroke Welsh Corgi."
* "Search for chocolate."
* "More information." (followup after an initial summary)
* "Tell me more." (followup after an initial summary)

# Platform support

- :heavy_check_mark: - tested and confirmed working
- :x: - incompatible/non-functional
- :question: - untested
- :construction: - partial support

|     platform    |   status   |  tag  | version | last tested | 
|:---------------:|:----------:|:-----:|:-------:|:-----------:|
|    [Chatterbox](https://hellochatterbox.com)   | :question: |  dev  |         |    never    | 
|     [HolmesV](https://github.com/HelloChatterbox/HolmesV)     | :question: |  dev  |         |    never    | 
|    [LocalHive](https://github.com/JarbasHiveMind/LocalHive)    | :question: |  dev  |         |    never    |  
|  [Mycroft Mark1](https://github.com/MycroftAI/enclosure-mark1)    | :question: |  dev  |         |    never    | 
|  [Mycroft Mark2](https://github.com/MycroftAI/hardware-mycroft-mark-II)    | :question: |  dev  |         |    never    |  
|    [NeonGecko](https://neon.ai)      | :question: |  dev  |         |    never    |   
|       [OVOS](https://github.com/OpenVoiceOS)        | :question: |  dev  |         |    never    |    
|     [Picroft](https://github.com/MycroftAI/enclosure-picroft)       | :question: |  dev  |         |    never    |  
| [Plasma Bigscreen](https://plasma-bigscreen.org/)  | :question: |  dev  |         |    never    |  

- `tag` - link to github release / branch / commit
- `version` - link to release/commit of platform repo where this was tested

## Credits
[JarbasAl](https://github.com/JarbasAl)
[NeonDaniel](https://github.com/NeonDaniel)

## Category
**Information**

## Tags
#wikipedia
#encyclopedia
#general-knowledge
#wiki
#question
#query
#Neon Enhanced
